@@ -6,12 +6,11 @@ See the `NOTICE <https://github.com/sloria/marshmallow/blob/master/NOTICE>`_
 file for more licensing information.
 '''
 from __future__ import absolute_import
-from decimal import Decimal as MyDecimal, ROUND_HALF_EVEN
-from collections import OrderedDict
+from decimal import Decimal as MyDecimal, ROUND_HALF_EVEN, Inexact, Context
 
 from marshmallow import core, types
 from marshmallow.base import Field
-from marshmallow.compat import text_type
+from marshmallow.compat import text_type, OrderedDict
 from marshmallow.exceptions import MarshallingException
 
 
@@ -61,6 +60,19 @@ def _to_marshallable_type(obj):
     return dict(obj.__dict__)
 
 
+def float_to_decimal(f):
+    "Convert a floating point number to a Decimal with no loss of information"
+    n, d = f.as_integer_ratio()
+    numerator, denominator = MyDecimal(n), MyDecimal(d)
+    ctx = Context(prec=60)
+    result = ctx.divide(numerator, denominator)
+    while ctx.flags[Inexact]:
+        ctx.flags[Inexact] = False
+        ctx.prec *= 2
+        result = ctx.divide(numerator, denominator)
+    return result
+
+
 class Raw(Field):
     """Basic field from which other fields should extend. It applies no
     formatting by default, and should only be used in cases where
@@ -107,14 +119,14 @@ class Raw(Field):
 
 
 class Nested(Raw):
-    """Allows you to nest a :class:`Serializer <marshmallow.core.Serializer>`
+    """Allows you to nest a :class:`Serializer <marshmallow.Serializer>`
     or set of fields inside a field.
 
     Example: ::
 
         user = fields.Nested(UserSerializer)
 
-    :param Serializer nested: The Serializer class or dictionary to nest.
+    :param Serializer nested: The Serializer class or instance to nest.
     :param bool exclude: A list or tuple of fields to exclude.
     :param bool only: A list or tuple of fields to marshal. If ``None``, all fields
         will be marshalled. Takes precedence over ``exclude``.
@@ -123,8 +135,14 @@ class Nested(Raw):
     """
 
     def __init__(self, nested, exclude=None, only=None, allow_null=False, **kwargs):
-        nested_obj = nested() if isinstance(nested, type) else nested
-        self.nested =  nested_obj.fields if issubclass(nested, core.Serializer) else nested_obj
+        try:
+            if issubclass(nested, core.Serializer):
+                self.serializer = nested()
+        except TypeError:
+            if isinstance(nested, core.Serializer):
+                self.serializer = nested
+
+        self.nested =  self.serializer.fields
         self.allow_null = allow_null
         # Marshall all fields by default
         self.only = set(self.nested) if only is None else set(only)
@@ -142,7 +160,11 @@ class Nested(Raw):
         filtered = ((k, v) for k, v in self.nested.items()
                     if k in self.only and k not in self.exclude)
         fields = OrderedDict(filtered)
-        return core.marshal(value, fields)
+        ret = self.serializer.marshal(value, fields)
+        # Parent should get any errors stored after marshalling
+        if self.serializer.errors:
+            self.parent.errors[key] = self.serializer.errors
+        return ret
 
 
 class List(Raw):
@@ -268,8 +290,8 @@ class Arbitrary(NumberField):
     def format(self, value):
         try:
             if value is None:
-                return text_type(MyDecimal(self.default))
-            return text_type(MyDecimal(value))
+                return text_type(float_to_decimal(float(self.default)))
+            return text_type(float_to_decimal(float(value)))
         except ValueError as ve:
             raise MarshallingException(ve)
 
@@ -313,7 +335,7 @@ class Fixed(NumberField):
 
     def format(self, value):
         try:
-            dvalue = MyDecimal(value)
+            dvalue = float_to_decimal(float(value))
         except ValueError as ve:
             raise MarshallingException(ve)
         if not dvalue.is_normal() and dvalue != ZERO:
